@@ -1,11 +1,14 @@
+from __future__ import annotations
+
 import urwid
 
+
 class QuestionnaireItem(urwid.WidgetWrap):
     def __init__(self):
         self.options = []
-        unsure = urwid.RadioButton(self.options, u"Unsure")
-        yes = urwid.RadioButton(self.options, u"Yes")
-        no = urwid.RadioButton(self.options, u"No")
+        unsure = urwid.RadioButton(self.options, "Unsure")
+        yes = urwid.RadioButton(self.options, "Yes")
+        no = urwid.RadioButton(self.options, "No")
         display_widget = urwid.GridFlow([unsure, yes, no], 15, 3, 1, 'left')
         urwid.WidgetWrap.__init__(self, display_widget)
 
