@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import urwid
 
+
 def exit_on_q(key):
     if key in ('q', 'Q'):
         raise urwid.ExitMainLoop()
@@ -20,7 +23,7 @@ loop.widget.original_widget = urwid.Filler(urwid.Pile([]))
 div = urwid.Divider()
 outside = urwid.AttrMap(div, 'outside')
 inside = urwid.AttrMap(div, 'inside')
-txt = urwid.Text(('banner', u" Hello World "), align='center')
+txt = urwid.Text(('banner', " Hello World "), align='center')
 streak = urwid.AttrMap(txt, 'streak')
 pile = loop.widget.base_widget # .base_widget skips the decorations
 for item in [outside, inside, streak, inside, outside]:
