@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import urwid
 
+
 def exit_on_q(key):
     if key in ('q', 'Q'):
         raise urwid.ExitMainLoop()
@@ -7,12 +10,11 @@ def exit_on_q(key):
 class QuestionBox(urwid.Filler):
     def keypress(self, size, key):
         if key != 'enter':
-            return super(QuestionBox, self).keypress(size, key)
+            return super().keypress(size, key)
         self.original_widget = urwid.Text(
-            u"Nice to meet you,\n%s.\n\nPress Q to exit." %
-            edit.edit_text)
+            f"Nice to meet you,\n{edit.edit_text}.\n\nPress Q to exit.")
 
-edit = urwid.Edit(u"What is your name?\n")
+edit = urwid.Edit("What is your name?\n")
 fill = QuestionBox(edit)
 loop = urwid.MainLoop(fill, unhandled_input=exit_on_q)
 loop.run()
